#
# spec file for package python-pyvmomi
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2014 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pyvmomi
VCS: https://src.suse.de/SLFO-pool/python-pyvmomi#870f8f7b573d6239fe69f3c24e9d56438b3feb8b670932bca95641f8d0136202
Version:        8.0.3.0.1
Release:        160000.1.4
Summary:        VMware vSphere Python SDK
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/vmware/pyvmomi
Source:         https://github.com/vmware/pyvmomi/archive/v%{version}.tar.gz#/pyvmomi-%{version}.tar.gz
Patch0:         0001-pyVmomi-pinned-certificates-support.patch
BuildRequires:  %{python_module fixtures >= 1.3.0}
BuildRequires:  %{python_module requests >= 2.3.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.7.3}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module testtools >= 0.9.34}
BuildRequires:  %{python_module vcrpy}
# /SECTION
Requires:       python-requests >= 2.3.0
Requires:       python-six >= 1.7.3
Recommends:     python-lxml
Recommends:     python-pyOpenSSL
BuildArch:      noarch
%python_subpackages

%description
pyVmomi is the Python SDK for the VMware vSphere API that allows you to manage
ESX, ESXi, and vCenter.

%prep
%setup -q -n pyvmomi-%{version}%{?version_suffix}
%autopatch -p1
dos2unix README.rst LICENSE.txt NOTICE.txt

# https://github.com/vmware/pyvmomi/pull/750
# Unpin vcrpy; the fix was released
sed -i 's/vcrpy<2/vcrpy/' test-requirements.txt

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm tests/test_json.py
rm tests/test_connect.py
rm tests/test_pbm_check_compatibility.py
%pyunittest discover -v

%files %{python_files}
%license LICENSE.txt
%doc NOTICE.txt README.rst
%{python_sitelib}/pyVim
%{python_sitelib}/pyVmomi
%{python_sitelib}/vsanapiutils.py
%{python_sitelib}/vsanmgmtObjects.py
%{python_sitelib}/pyvmomi-%{version}*-py*.egg-info
%pycache_only %{python_sitelib}/__pycache__

%changelog
* Fri Jan 31 2025 daniel.garcia@suse.com
- Remove not needed BuildRequires tox
* Mon Sep 16 2024 mardnh@gmx.de
- Update to version 8.0.3.0.1
  Bindings
  * Added support for vSAN Health APIs
  * Updated bindings with support for the new vSphere 8.0U3 APIs.
  * New features of vSphere 8.0U3 based on REST APIs are available
    via the vSphere Automation SDK for Python
  Type Hints
  * Added type stubs for vSAN APIs.
  * All type stubs are refactored.
  Added
  * Python 3.12 compatibility
  * Stub adapters allow the usage of an existing session.
  * Added pyVmomi version in the user-agent request header
  * Added certFile and certKeyFile attributes to SoapStubAdapter.
  * Added project wide variables to hold the current pyVmomi version,
    version_info and version_info_str
  * Added functions to VmomiSupport to list all types
    ListManagedTypes(), ListDataTypes(), ListEnumTypes().
  Changes
  * Doc: Non-remote ManagedObject and DataObject methods are
    documented.
  * The support statement now reflects the Broadcom support policy.
  * Copyright switch from VMware to Broadcom.
  Breaking changes
  * sso.SsoAuthenticator.get_bearer_saml_assertion_gss_api() is
    removed.
  * SSLTunnelConnection is trimmed down to handle only tunnel
    connections. The code that handles remote proxy doubles the
    HTTPProxyConnection logic and therefore is removed.
  Deprecated
  * 'publicVersions' and 'dottedVersions' aliases are deprecated.
  * pyVmomiSettings.py and related settings are deprecated
    allowGetSet, allowCapitalizedNames, binaryIsBytearray,
    legacyThumbprintException.
  * Features.py and all pyVmomi feature states logic is deprecated
  * pyVmomi.VmomiSupport.VmomiJSONEncoder is deprecated.
    Use pyVmomi.VmomiJSONEncoder.VmomiJSONEncoder
  * pyVmomi.VmomiSupport.templateOf() is deprecated.
    Use pyVmomi.VmomiJSONEncoder.templateOf()
  * pyVmomi.SoapAdapter.ThumbprintMismatchException is deprecated.
    Use pyVmomi.Security.ThumbprintMismatchException
- Update to version 8.0.2.0.1
  Maintenance Patch 1 for 8.0U2 - 2023-11-17
  Changes
  * Fixed: #978 and #1053 - Fix SmartConnect()'s handling of IPv6
    address with square brackets
  * Added PyPI classifiers for Python 3.10 and Python 3.11.
    Support for both versions is verified.
- Update to version 8.0.2.0
  Bindings
  * Updated bindings and type hints with support for vSphere 8.0U2.
    Includes updates to VIM, PBM, EAM, SMS and VSLM namespaces.
  * New features of vSphere 8.0U2 based on REST APIs are available
    via the vSphere Automation SDK for Python
    https://github.com/vmware/vsphere-automation-sdk-python
- Update to version 8.0.1.0.2
  Bindings
  * Added bindings and type hints for Virtual Storage Lifecycle
    Management for vSphere 8.0U1 - VSLM namespace.
  Changes
  * Fixed: #1021 - Switch to static imports for type info modules.
  * Fixed: #1022 - Support proxy authentication.
  * Add custom HTTP headers support to connect.SmartStubAdapter().
  * Missing filters are no longer treated as task failures.
  * Various small fixes for docstrings and linter checks.
  Type Hints Fixes
  * Fixed: #1026 - Use the "from Y import X as X" format to
    re-export submodules.
  * Fixed: #1030 - Use a fully qualified name when the type is from
    another namespace/package
  Tests
  * vcrpy dependency is updated to the latest version with Python 2
    support.
  * testtools dependency is removed.
  * Travis CI is no longer used.
  * Various test updates and fixes. All tests are enabled.
- Update to version 8.0.1.0.1
  Type Hints Fixes
  * Added missing VMODL1 classes to the type hints
  * Enum values now match the letter case of the values from
    typeinfo files.
  * Fixed: #1115 - Syntax error in vim/__init__pyi.
  * Fixed: #1117 - Type stubs: Writable properties are marked as
    read-only.
  * Fixed: #1118 - Type stubs: Missing vim.fault.* and
    vmodl.fault.* types
  * Fixed: #1119 - Type stubs: Enum fields should also accept
    Literal[] str type.
  * Fixed: #1120 - Type stubs: Exception types must inherit from
    (Base)Exception.
- Update to version 8.0.1.0
  Bindings
  * Updated bindings with support for vSphere 8.0U1. Includes
    updates to VIM, PBM, EAM and SMS namespaces.
  * New features of vSphere 8.0U1 based on REST APIs are available
    via the vSphere Automation SDK for Python.
  Changes
  * Added support for type hints.
  * #892 - Allow passing ssl_context when login in with a token.
  * Fixed: #750 - Bumped vcrpy tests dependency to 2.1.
  * Fixed: #812 - Fix exception leaks.
  * Fixed: #1004 - Fix SmartConnect()'s SOAP and OAuth token login.
- Update to version 8.0.0.1.1
  Changes
  * Fixed: #993 - WaitForTask broken on version >8.0.0.
  * Fixed: #994 - Pyvomi module failing in connect method.
  * Replace publicVersions with ltsVersions.
  * Updated VIM namespace for the next vSphere 8.0 patch release.
- Update to version 8.0.0.1
  Bindings
  * Updated bindings with support for vSphere 8.0. Includes updates
  * New features of vSphere 8.0 based on REST APIs are available
    via the vSphere Automation SDK for Python.
  Breaking changes
  * Minimum Python 2 requirement is 2.7.9.
  * DynamicTypeManagerHelper.py is removed.
  * ManagedMethodExecutorHelper.py is removed.
  * connect.ConnectNoSSL() and connect.SmartConnectNoSSL() are
    removed. Use connect.Connect(disableSslCertValidation=True)
    and connect.SmartConnect(disableSslCertValidation=True)
  * VmomiSupport.UncallableManagedMethod is renamed to
    VmomiSupport.UnknownManagedMethod.
  New modules
  * Security.py A new module is added to handle thumbprint
    verification. There is a predefined set of available crypto
    functions to verify the certificate thumbprints. Its possible
    to configure during runtime which of the available crypto
    functions are allowed.
  * Feature.py A new module related to pyVmomi development within
    VMware.
  * VmomiJSONEncoder.py The VmomiJSONEncoder is moved into a
    dedicated module.
  More changes
  * A new 'binaryIsBytearray' setting is added to select the base
    type for the binary type. By default, the binary type is 'str'
    for Python 2 and 'bytes' for Python 3. If binaryIsBytearray is
    True, the binary type for Python 2 is set to 'bytearray'.
    Required for VmomiJSONEncoder to work properly.
  * The license note is removed from the Python files. LICENSE.txt
    holds the Apache 2 license note.
  * pyVmomi now uses relative imports
  * Dependency on "requests" is removed
  * Added support for SAML token authentication
  * Added timeout for HTTP requests
  * Added option to set the maximum amount of time a task is
    allowed to run. On timeout, an exception is generated if
    raiseOnError is True.
  * Add option to get all updates for the task.
  * Add option to use a logger instead of the standard output.
  * Various bug fixes
  * Code style improvements
  Deprecated
  * connect.OpenUrlWithBasicAuth()
  * connect.OpenPathWithStub()
- Add patch
  * 0001-pyVmomi-pinned-certificates-support.patch
- Reenable python3.12 builds
* Mon Apr  8 2024 opensuse_buildservice@ojkastl.de
- add sle15 macro; disable python3.12 builds
* Thu Apr 14 2022 pgajdos@suse.com
- python-mock is not required for build
* Mon Oct 25 2021 mardnh@gmx.de
- Update to version 7.0.3
  * Added new bindings to support vSphere 7.0U3. Includes updates
    to VIM, PBM, EAM and SMS namespaces.
  * New features of vSphere 7.0U3 based on REST APIs are available
    via the vSphere Automation SDK for Python.
  * Outdated samples are removed. Community samples project:
    https://github.com/vmware/pyvmomi-community-samples
  * Bindings files are renamed to _typeinfo_{namespace}.py
  * "stable" version alias is removed
  * "public" version alias is renamed to "LTS"
* Fri May 28 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Fri Apr  9 2021 mardnh@gmx.de
- Update to version 7.0.2
  * Added new bindings to support vSphere 7.0U2. Includes updates
    to VIM, PBM, EAM and SMS namespaces. For details, refer
    “What’s New in vSphere API 7.0U2?” section in the API
    reference guide: https://code.vmware.com/apis/1131/vsphere
* Sat Oct 31 2020 mardnh@gmx.de
- update to version 7.0.1
  * Added new bindings to support vSphere 7.0U1. Includes updates
    to VIM, PBM, and EAM namespaces. For details, refer “What’s
    New in vSphere API 7.0U1?” section in the API reference guide:
    https://code.vmware.com/apis/1067/vsphere
  * New features of vSphere 7.0U1 based on REST APIs are available
    via the vSphere Automation SDK for Python:
    https://github.com/vmware/vsphere-automation-sdk-python
- Switch to github source url
* Tue Apr 14 2020 mardnh@gmx.de
- update to version 7.0
  * Added new bindings to support vSphere 7.0. For details, refer
    "What’s New in vSphere API 7.0?" section in the API reference
    guide: https://code.vmware.com/apis/968/vsphere
  * New features of vSphere 7.0 based on REST APIs are available
    via the vSphere Automation SDK for Python:
    https://github.com/vmware/vsphere-automation-sdk-python
* Sun Sep 15 2019 jayvdb@gmail.com
- Add runtime recommends for pyOpenSSL and lxml, needed for SSO support
- Update to v6.7.3
  * Publish new bindings to support vSphere 6.7 Update 3 Release
  * Add sso.py to support get bearer/hok token from sso server
  * pydoc support Fix
  * httpProxy Support Fix
  * Changes to VmomiSupport to handle API versions
- Convert line endings on README.rst
- Drop python-pyvmomi-fix-incompatibility-with-vcrpy2.patch as the
  vcrpy fix has been released
* Sat Dec 29 2018 mardnh@gmx.de
- Update to version 6.7.1.2018.12
  * Support JSON encoding for pyVmomi objects
  * Fix vcrpy hardening in test-requirements. Support versions < 2.0
  * Delete deprecated Docs folder
- Add patch:
  * python-pyvmomi-fix-incompatibility-with-vcrpy2.patch
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Nov 21 2018 santiago.zarate@suse.com
  _ Update to version 6.7.1
  * Publish new bindings to support vSphere 6.7 Update 1 Release
  * Newer features are available via the new vSphere Automation SDK for Python
* Wed Apr 18 2018 mardnh@gmx.de
- Update to version 6.7
  * Publish new bindings to support vSphere 6.7
- Change URL to download sources from github
- Remove hotfix macro
- Enable tests
* Sat Mar  3 2018 arun@gmx.de
- specfile:
  * update copyright year
  * don't use python_module for Requires
* Wed Nov 29 2017 boris@steki.net
- updated to release v6.5.0.2017.5-1
  + Fix SoapAdapter serializer to support serializing unicode chars
  + Remove custom getattr in _HTTPSConnection
  + Add user-agent header when connecting to vsphere
- moved to single spec logic to build py2 and py3 package
* Sun Jan 15 2017 hpj@urpla.net
- fix build: add python-fixtures to build dependencies
* Thu Jan 12 2017 mardnh@gmx.de
- Update to version 6.5
  * Spec bump to support vSphere 6.5.
  * Include EAM bindings to support vSphere EAM service.
  * Fixed server thumbprint verification.
  * Fixed sslcontext creation in sample code.
* Sun Sep 18 2016 mardnh@gmx.de
- Update to version 6.0.0.2016.4
  * Python3 related bug fixes.
  * Include task.py utility class.
- Changes from version 6.0.0
  * Spec bump to support vSphere 6.0 server objects and types
    vSphere 6.0 U1 spec is used
  * New ssl context parameter in Connect.py and SoapAdapter.py to
    support passing various ssl options while connecting to vSphere.
  * Drop python 2.6 support.
  * Critical bug fixes.
- Remove patch: pyvmomi-git20141104-new.diff (fixed upstream)
- Fix Source-Url
* Wed May 13 2015 mc@suse.com
- add requires for python-six and python-requests
* Tue Nov  4 2014 hpj@urpla.net
- version 5.5.0.2014.1.1: initial build
- apply asorted fixes from todays git tree
